Module copc

Module copc 

COPC header data

Structs

CopcEntryReader
Entry Reader can read whole entries of copc laz files A reader for COPC (Cloud Optimized Point Cloud) entries that handles decompression and point reading.
CopcHierarchyVlr
The hierarchy VLR MUST exist.
CopcInfoVlr
The COPC Info Vlr.
Entry
An entry corresponds to a single key/value pair in an EPT hierarchy, but contains additional information to allow direct access and decoding of the corresponding point data.
EntryIterator
An iterator over COPC entries that handles references to sub-pages.
VoxelKey
VoxelKey corresponds to the naming of EPT data files.

Constants

DESCRIPTION
The description of the LasZip VLR header.
USER_ID
The user id of the LasZip VLR header.